==> jc-1.4.0.tar.gz: soot/jbuddy/SWIGTYPE__5fp__5fFILE.h <==
// public class soot.jbuddy.SWIGTYPE_p_FILE

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 195d0916b91805c4 soot_jbuddy_SWIGTYPE__5fp__5fFILE

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jbuddy_SWIGTYPE__5fp__5fFILE_H_
#define _JC_soot_jbuddy_SWIGTYPE__5fp__5fFILE_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object;

// Typedefs
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object;

typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype;

// Constructors
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object *);
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$method$_init$e037f92e255e7cc9(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object *, jlong, jboolean);

// Static methods
extern jlong _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$method$getCPtr$ce93c0ef8c64c483(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object *);

// Virtual methods structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods {
};

// Vtable
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods	soot_jbuddy_SWIGTYPE__5fp__5fFILE;
};

// Vtype
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype {
	_jc_type			type;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs {
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs	soot_jbuddy_SWIGTYPE__5fp__5fFILE;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs {
	jlong	swigCPtr;
};

// Non-reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs	soot_jbuddy_SWIGTYPE__5fp__5fFILE;
};

// Object instance structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object {
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype	*vtype;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jbuddy_SWIGTYPE__5fp__5fFILE, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$class_object;

#endif	/* _JC_soot_jbuddy_SWIGTYPE__5fp__5fFILE_H_ */

==> jc-1.4.6.tar.gz: soot/jbuddy/SWIGTYPE__5fp__5fFILE.h <==
// public class soot.jbuddy.SWIGTYPE_p_FILE

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195d0916b91805c4 soot_jbuddy_SWIGTYPE__5fp__5fFILE

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jbuddy_SWIGTYPE__5fp__5fFILE_H_
#define _JC_soot_jbuddy_SWIGTYPE__5fp__5fFILE_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object;

// Typedefs
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs;
typedef struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object;

typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable;
typedef const struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype;

// Constructors
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$method$_init$e037f92e255e7cc9(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object *, jlong, jboolean) _JC_JCNI_ATTR;

// Static methods
extern jlong _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$method$getCPtr$ce93c0ef8c64c483(_jc_env *, struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods {
};

// Vtable
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vmethods	soot_jbuddy_SWIGTYPE__5fp__5fFILE;
};

// Vtype
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype {
	_jc_type			type;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs {
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_refs	soot_jbuddy_SWIGTYPE__5fp__5fFILE;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs {
	jlong	swigCPtr;
};

// Non-reference instance fields (object)
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$sub_nonrefs	soot_jbuddy_SWIGTYPE__5fp__5fFILE;
};

// Object instance structure
struct _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$object {
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype	*vtype;
	_jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$vtype _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jbuddy_SWIGTYPE__5fp__5fFILE, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jbuddy_SWIGTYPE__5fp__5fFILE$class_object;

#endif	/* _JC_soot_jbuddy_SWIGTYPE__5fp__5fFILE_H_ */
